from google.protobuf import wrappers_pb2 as _wrappers_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AliasType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    DEFAULT: _ClassVar[AliasType]
    CL5SID: _ClassVar[AliasType]
DEFAULT: AliasType
CL5SID: AliasType

class Service(_message.Message):
    __slots__ = ["name", "namespace", "metadata", "ports", "business", "department", "cmdb_mod1", "cmdb_mod2", "cmdb_mod3", "comment", "owners", "token", "ctime", "mtime", "revision", "platform_id", "total_instance_count", "healthy_instance_count", "user_ids", "group_ids", "remove_user_ids", "remove_group_ids", "id", "editable", "export_to"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    BUSINESS_FIELD_NUMBER: _ClassVar[int]
    DEPARTMENT_FIELD_NUMBER: _ClassVar[int]
    CMDB_MOD1_FIELD_NUMBER: _ClassVar[int]
    CMDB_MOD2_FIELD_NUMBER: _ClassVar[int]
    CMDB_MOD3_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    HEALTHY_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_USER_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    EXPORT_TO_FIELD_NUMBER: _ClassVar[int]
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    metadata: _containers.ScalarMap[str, str]
    ports: _wrappers_pb2.StringValue
    business: _wrappers_pb2.StringValue
    department: _wrappers_pb2.StringValue
    cmdb_mod1: _wrappers_pb2.StringValue
    cmdb_mod2: _wrappers_pb2.StringValue
    cmdb_mod3: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    owners: _wrappers_pb2.StringValue
    token: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    platform_id: _wrappers_pb2.StringValue
    total_instance_count: _wrappers_pb2.UInt32Value
    healthy_instance_count: _wrappers_pb2.UInt32Value
    user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    id: _wrappers_pb2.StringValue
    editable: _wrappers_pb2.BoolValue
    export_to: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    def __init__(self, name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., ports: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., business: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., department: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., cmdb_mod1: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., cmdb_mod2: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., cmdb_mod3: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owners: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., platform_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., total_instance_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., healthy_instance_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., editable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., export_to: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ...) -> None: ...

class ServiceAlias(_message.Message):
    __slots__ = ["service", "namespace", "alias", "alias_namespace", "type", "owners", "comment", "service_token", "ctime", "mtime", "id", "editable"]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    ALIAS_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    alias: _wrappers_pb2.StringValue
    alias_namespace: _wrappers_pb2.StringValue
    type: AliasType
    owners: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    service_token: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    id: _wrappers_pb2.StringValue
    editable: _wrappers_pb2.BoolValue
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., alias: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., alias_namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., type: _Optional[_Union[AliasType, str]] = ..., owners: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., editable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...) -> None: ...

class Instance(_message.Message):
    __slots__ = ["id", "service", "namespace", "vpc_id", "host", "port", "protocol", "version", "priority", "weight", "enable_health_check", "health_check", "healthy", "isolate", "location", "metadata", "logic_set", "ctime", "mtime", "revision", "service_token"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    VPC_ID_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    ENABLE_HEALTH_CHECK_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_FIELD_NUMBER: _ClassVar[int]
    HEALTHY_FIELD_NUMBER: _ClassVar[int]
    ISOLATE_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LOGIC_SET_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    vpc_id: _wrappers_pb2.StringValue
    host: _wrappers_pb2.StringValue
    port: _wrappers_pb2.UInt32Value
    protocol: _wrappers_pb2.StringValue
    version: _wrappers_pb2.StringValue
    priority: _wrappers_pb2.UInt32Value
    weight: _wrappers_pb2.UInt32Value
    enable_health_check: _wrappers_pb2.BoolValue
    health_check: HealthCheck
    healthy: _wrappers_pb2.BoolValue
    isolate: _wrappers_pb2.BoolValue
    location: _model_pb2.Location
    metadata: _containers.ScalarMap[str, str]
    logic_set: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    service_token: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., vpc_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., host: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., port: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., protocol: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., priority: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., weight: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., enable_health_check: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., health_check: _Optional[_Union[HealthCheck, _Mapping]] = ..., healthy: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., isolate: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., location: _Optional[_Union[_model_pb2.Location, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., logic_set: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class HealthCheck(_message.Message):
    __slots__ = ["type", "heartbeat"]
    class HealthCheckType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[HealthCheck.HealthCheckType]
        HEARTBEAT: _ClassVar[HealthCheck.HealthCheckType]
    UNKNOWN: HealthCheck.HealthCheckType
    HEARTBEAT: HealthCheck.HealthCheckType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_FIELD_NUMBER: _ClassVar[int]
    type: HealthCheck.HealthCheckType
    heartbeat: HeartbeatHealthCheck
    def __init__(self, type: _Optional[_Union[HealthCheck.HealthCheckType, str]] = ..., heartbeat: _Optional[_Union[HeartbeatHealthCheck, _Mapping]] = ...) -> None: ...

class HeartbeatHealthCheck(_message.Message):
    __slots__ = ["ttl"]
    TTL_FIELD_NUMBER: _ClassVar[int]
    ttl: _wrappers_pb2.UInt32Value
    def __init__(self, ttl: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63lient.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\xf7\x02\n\x06\x43lient\x12*\n\x04host\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12#\n\x04type\x18\x02 \x01(\x0e\x32\x15.v1.Client.ClientType\x12-\n\x07version\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x08location\x18\x04 \x01(\x0b\x32\x0c.v1.Location\x12(\n\x02id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x04stat\x18\x06 \x03(\x0b\x32\x0c.v1.StatInfo\x12+\n\x05\x63time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"-\n\nClientType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03SDK\x10\x01\x12\t\n\x05\x41GENT\x10\x02\"\xc0\x01\n\x08StatInfo\x12,\n\x06target\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04port\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04path\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08protocol\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x8c\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0b\x43lientProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\013ClientProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_CLIENT']._serialized_start=66
  _globals['_CLIENT']._serialized_end=441
  _globals['_CLIENT_CLIENTTYPE']._serialized_start=396
  _globals['_CLIENT_CLIENTTYPE']._serialized_end=441
  _globals['_STATINFO']._serialized_start=444
  _globals['_STATINFO']._serialized_end=636
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from ..config_manage import config_file_pb2 as _config_file_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigSimpleResponse(_message.Message):
    __slots__ = ["code", "info"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ConfigResponse(_message.Message):
    __slots__ = ["code", "info", "configFileGroup", "configFile", "configFileRelease", "configFileReleaseHistory", "configFileTemplate"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILEGROUP_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILE_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILERELEASE_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILERELEASEHISTORY_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILETEMPLATE_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    configFileGroup: _config_file_pb2.ConfigFileGroup
    configFile: _config_file_pb2.ConfigFile
    configFileRelease: _config_file_pb2.ConfigFileRelease
    configFileReleaseHistory: _config_file_pb2.ConfigFileReleaseHistory
    configFileTemplate: _config_file_pb2.ConfigFileTemplate
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., configFileGroup: _Optional[_Union[_config_file_pb2.ConfigFileGroup, _Mapping]] = ..., configFile: _Optional[_Union[_config_file_pb2.ConfigFile, _Mapping]] = ..., configFileRelease: _Optional[_Union[_config_file_pb2.ConfigFileRelease, _Mapping]] = ..., configFileReleaseHistory: _Optional[_Union[_config_file_pb2.ConfigFileReleaseHistory, _Mapping]] = ..., configFileTemplate: _Optional[_Union[_config_file_pb2.ConfigFileTemplate, _Mapping]] = ...) -> None: ...

class ConfigBatchWriteResponse(_message.Message):
    __slots__ = ["code", "info", "total", "responses"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    total: _wrappers_pb2.UInt32Value
    responses: _containers.RepeatedCompositeFieldContainer[ConfigResponse]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., total: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., responses: _Optional[_Iterable[_Union[ConfigResponse, _Mapping]]] = ...) -> None: ...

class ConfigBatchQueryResponse(_message.Message):
    __slots__ = ["code", "info", "total", "configFileGroups", "configFiles", "configFileReleases", "configFileReleaseHistories", "configFileTemplates"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILEGROUPS_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILES_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILERELEASES_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILERELEASEHISTORIES_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILETEMPLATES_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    total: _wrappers_pb2.UInt32Value
    configFileGroups: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFileGroup]
    configFiles: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFile]
    configFileReleases: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFileRelease]
    configFileReleaseHistories: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFileReleaseHistory]
    configFileTemplates: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFileTemplate]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., total: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., configFileGroups: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFileGroup, _Mapping]]] = ..., configFiles: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFile, _Mapping]]] = ..., configFileReleases: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFileRelease, _Mapping]]] = ..., configFileReleaseHistories: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFileReleaseHistory, _Mapping]]] = ..., configFileTemplates: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFileTemplate, _Mapping]]] = ...) -> None: ...

class ConfigClientResponse(_message.Message):
    __slots__ = ["code", "info", "configFile"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    CONFIGFILE_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    configFile: _config_file_pb2.ClientConfigFileInfo
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., configFile: _Optional[_Union[_config_file_pb2.ClientConfigFileInfo, _Mapping]] = ...) -> None: ...

class ConfigImportResponse(_message.Message):
    __slots__ = ["code", "info", "createConfigFiles", "skipConfigFiles", "overwriteConfigFiles"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    CREATECONFIGFILES_FIELD_NUMBER: _ClassVar[int]
    SKIPCONFIGFILES_FIELD_NUMBER: _ClassVar[int]
    OVERWRITECONFIGFILES_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    createConfigFiles: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFile]
    skipConfigFiles: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFile]
    overwriteConfigFiles: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ConfigFile]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., createConfigFiles: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFile, _Mapping]]] = ..., skipConfigFiles: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFile, _Mapping]]] = ..., overwriteConfigFiles: _Optional[_Iterable[_Union[_config_file_pb2.ConfigFile, _Mapping]]] = ...) -> None: ...

class ConfigExportResponse(_message.Message):
    __slots__ = ["code", "info", "data"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    data: _wrappers_pb2.BytesValue
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., data: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ...) -> None: ...

class ConfigEncryptAlgorithmResponse(_message.Message):
    __slots__ = ["code", "info", "algorithms"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    ALGORITHMS_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    algorithms: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., algorithms: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ...) -> None: ...

class ConfigClientListResponse(_message.Message):
    __slots__ = ["code", "info", "revision", "namespace", "group", "config_file_infos"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FILE_INFOS_FIELD_NUMBER: _ClassVar[int]
    code: _wrappers_pb2.UInt32Value
    info: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    namespace: str
    group: str
    config_file_infos: _containers.RepeatedCompositeFieldContainer[_config_file_pb2.ClientConfigFileInfo]
    def __init__(self, code: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., info: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[str] = ..., group: _Optional[str] = ..., config_file_infos: _Optional[_Iterable[_Union[_config_file_pb2.ClientConfigFileInfo, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncode.proto\x12\x02v1*\xbc%\n\x04\x43ode\x12\x0b\n\x07Unknown\x10\x00\x12\x14\n\x0e\x45xecuteSuccess\x10\xc0\x9a\x0c\x12\x12\n\x0c\x44\x61taNoChange\x10\xc1\x9a\x0c\x12\x12\n\x0cNoNeedUpdate\x10\xc2\x9a\x0c\x12\x10\n\nBadRequest\x10\x80\xb5\x18\x12\x14\n\x0eParseException\x10\x81\xb5\x18\x12\x12\n\x0c\x45mptyRequest\x10\x82\xb5\x18\x12\x18\n\x12\x42\x61tchSizeOverLimit\x10\x83\xb5\x18\x12\x1d\n\x17InvalidDiscoverResource\x10\x84\xb5\x18\x12\x16\n\x10InvalidRequestID\x10\xe4\xb5\x18\x12\x15\n\x0fInvalidUserName\x10\xe5\xb5\x18\x12\x16\n\x10InvalidUserToken\x10\xe6\xb5\x18\x12\x16\n\x10InvalidParameter\x10\xe7\xb5\x18\x12\x19\n\x13\x45mptyQueryParameter\x10\xe8\xb5\x18\x12\x1e\n\x18InvalidQueryInsParameter\x10\xe9\xb5\x18\x12\x1a\n\x14InvalidNamespaceName\x10\xee\xb5\x18\x12\x1c\n\x16InvalidNamespaceOwners\x10\xef\xb5\x18\x12\x1b\n\x15InvalidNamespaceToken\x10\xf0\xb5\x18\x12\x18\n\x12InvalidServiceName\x10\xf8\xb5\x18\x12\x1a\n\x14InvalidServiceOwners\x10\xf9\xb5\x18\x12\x19\n\x13InvalidServiceToken\x10\xfa\xb5\x18\x12\x1c\n\x16InvalidServiceMetadata\x10\xfb\xb5\x18\x12\x19\n\x13InvalidServicePorts\x10\xfc\xb5\x18\x12\x1c\n\x16InvalidServiceBusiness\x10\xfd\xb5\x18\x12\x1e\n\x18InvalidServiceDepartment\x10\xfe\xb5\x18\x12\x18\n\x12InvalidServiceCMDB\x10\xff\xb5\x18\x12\x1b\n\x15InvalidServiceComment\x10\x80\xb6\x18\x12 \n\x1aInvalidServiceAliasComment\x10\x81\xb6\x18\x12\x17\n\x11InvalidInstanceID\x10\x82\xb6\x18\x12\x19\n\x13InvalidInstanceHost\x10\x83\xb6\x18\x12\x19\n\x13InvalidInstancePort\x10\x84\xb6\x18\x12\x19\n\x13InvalidServiceAlias\x10\x85\xb6\x18\x12\x1f\n\x19InvalidNamespaceWithAlias\x10\x86\xb6\x18\x12\x1f\n\x19InvalidServiceAliasOwners\x10\x87\xb6\x18\x12\x1d\n\x17InvalidInstanceProtocol\x10\x88\xb6\x18\x12\x1c\n\x16InvalidInstanceVersion\x10\x89\xb6\x18\x12\x1d\n\x17InvalidInstanceLogicSet\x10\x8a\xb6\x18\x12\x1c\n\x16InvalidInstanceIsolate\x10\x8b\xb6\x18\x12\x18\n\x12HealthCheckNotOpen\x10\x8c\xb6\x18\x12\x1c\n\x16HeartbeatOnDisabledIns\x10\x8d\xb6\x18\x12\x1a\n\x14HeartbeatExceedLimit\x10\x8e\xb6\x18\x12\x1b\n\x15HeartbeatTypeNotFound\x10\x8f\xb6\x18\x12\x15\n\x0fInvalidMetadata\x10\x96\xb6\x18\x12\x18\n\x12InvalidRateLimitID\x10\x97\xb6\x18\x12\x1c\n\x16InvalidRateLimitLabels\x10\x98\xb6\x18\x12\x1d\n\x17InvalidRateLimitAmounts\x10\x99\xb6\x18\x12\x1a\n\x14InvalidRateLimitName\x10\x9a\xb6\x18\x12\x1d\n\x17InvalidCircuitBreakerID\x10\xa0\xb6\x18\x12\"\n\x1cInvalidCircuitBreakerVersion\x10\xa1\xb6\x18\x12\x1f\n\x19InvalidCircuitBreakerName\x10\xa2\xb6\x18\x12$\n\x1eInvalidCircuitBreakerNamespace\x10\xa3\xb6\x18\x12!\n\x1bInvalidCircuitBreakerOwners\x10\xa4\xb6\x18\x12 \n\x1aInvalidCircuitBreakerToken\x10\xa5\xb6\x18\x12#\n\x1dInvalidCircuitBreakerBusiness\x10\xa6\xb6\x18\x12%\n\x1fInvalidCircuitBreakerDepartment\x10\xa7\xb6\x18\x12\"\n\x1cInvalidCircuitBreakerComment\x10\xa8\xb6\x18\x12\x1f\n\x19\x43ircuitBreakerRuleExisted\x10\xa9\xb6\x18\x12\x16\n\x10InvalidRoutingID\x10\xbc\xba\x18\x12\x1a\n\x14InvalidRoutingPolicy\x10\xbd\xba\x18\x12\x18\n\x12InvalidRoutingName\x10\xbe\xba\x18\x12\x1c\n\x16InvalidRoutingPriority\x10\xbf\xba\x18\x12\x1a\n\x14InvalidFaultDetectID\x10\x84\xbc\x18\x12\x1c\n\x16InvalidFaultDetectName\x10\x85\xbc\x18\x12!\n\x1bInvalidFaultDetectNamespace\x10\x86\xbc\x18\x12\x1c\n\x16\x46\x61ultDetectRuleExisted\x10\x87\xbc\x18\x12\x16\n\x10InvalidMatchRule\x10\x88\xbc\x18\x12\x19\n\x13ServicesExistedMesh\x10\xaa\xb6\x18\x12\x1a\n\x14ResourcesExistedMesh\x10\xab\xb6\x18\x12\x1a\n\x14InvalidMeshParameter\x10\xac\xb6\x18\x12\x17\n\x11InvalidPlatformID\x10\xb4\xb6\x18\x12\x19\n\x13InvalidPlatformName\x10\xb5\xb6\x18\x12\x1b\n\x15InvalidPlatformDomain\x10\xb6\xb6\x18\x12\x18\n\x12InvalidPlatformQPS\x10\xb7\xb6\x18\x12\x1a\n\x14InvalidPlatformToken\x10\xb8\xb6\x18\x12\x1a\n\x14InvalidPlatformOwner\x10\xb9\xb6\x18\x12\x1f\n\x19InvalidPlatformDepartment\x10\xba\xb6\x18\x12\x1c\n\x16InvalidPlatformComment\x10\xbb\xb6\x18\x12\x16\n\x10NotFoundPlatform\x10\xbc\xb6\x18\x12\x1c\n\x16InvalidFluxRateLimitId\x10\xbe\xb6\x18\x12\x1d\n\x17InvalidFluxRateLimitQps\x10\xbf\xb6\x18\x12 \n\x1aInvalidFluxRateLimitSetKey\x10\xc0\xb6\x18\x12\x15\n\x0f\x45xistedResource\x10\xc9\xb6\x18\x12\x16\n\x10NotFoundResource\x10\xca\xb6\x18\x12\x1e\n\x18NamespaceExistedServices\x10\xcb\xb6\x18\x12\x1d\n\x17ServiceExistedInstances\x10\xcc\xb6\x18\x12\x1c\n\x16ServiceExistedRoutings\x10\xcd\xb6\x18\x12\x1e\n\x18ServiceExistedRateLimits\x10\xce\xb6\x18\x12\x19\n\x13\x45xistReleasedConfig\x10\xcf\xb6\x18\x12\x19\n\x13SameInstanceRequest\x10\xd0\xb6\x18\x12#\n\x1dServiceExistedCircuitBreakers\x10\xd1\xb6\x18\x12\x19\n\x13ServiceExistedAlias\x10\xd2\xb6\x18\x12#\n\x1dNamespaceExistedMeshResources\x10\xd3\xb6\x18\x12%\n\x1fNamespaceExistedCircuitBreakers\x10\xd4\xb6\x18\x12\x1f\n\x19ServiceSubscribedByMeshes\x10\xd5\xb6\x18\x12\"\n\x1cServiceExistedFluxRateLimits\x10\xd6\xb6\x18\x12\"\n\x1cNamespaceExistedConfigGroups\x10\xdb\xb6\x18\x12\x15\n\x0fNotFoundService\x10\xad\xb7\x18\x12\x15\n\x0fNotFoundRouting\x10\xae\xb7\x18\x12\x16\n\x10NotFoundInstance\x10\xaf\xb7\x18\x12\x1a\n\x14NotFoundServiceAlias\x10\xb0\xb7\x18\x12\x17\n\x11NotFoundNamespace\x10\xb1\xb7\x18\x12\x1b\n\x15NotFoundSourceService\x10\xb2\xb7\x18\x12\x17\n\x11NotFoundRateLimit\x10\xb3\xb7\x18\x12\x1c\n\x16NotFoundCircuitBreaker\x10\xb4\xb7\x18\x12\x1a\n\x14NotFoundMasterConfig\x10\xb5\xb7\x18\x12\x17\n\x11NotFoundTagConfig\x10\xb6\xb7\x18\x12 \n\x1aNotFoundTagConfigOrService\x10\xb7\xb7\x18\x12\x16\n\x10\x43lientAPINotOpen\x10\x91\xb8\x18\x12\x1d\n\x17NotAllowBusinessService\x10\x92\xb8\x18\x12\x19\n\x13NotAllowAliasUpdate\x10\xf5\xb8\x18\x12!\n\x1bNotAllowAliasCreateInstance\x10\xf6\xb8\x18\x12 \n\x1aNotAllowAliasCreateRouting\x10\xf7\xb8\x18\x12!\n\x1bNotAllowCreateAliasForAlias\x10\xf8\xb8\x18\x12\"\n\x1cNotAllowAliasCreateRateLimit\x10\xf9\xb8\x18\x12\x1b\n\x15NotAllowAliasBindRule\x10\xfa\xb8\x18\x12(\n\"NotAllowDifferentNamespaceBindRule\x10\xfb\xb8\x18\x12\x12\n\x0cUnauthorized\x10\xe8\xbc\x18\x12\x16\n\x10NotAllowedAccess\x10\xe9\xbc\x18\x12\x15\n\x0f\x43MDBNotFindHost\x10\xa1\xd4\x18\x12\x12\n\x0c\x44\x61taConflict\x10\xa8\xfb\x18\x12\x1d\n\x17InstanceTooManyRequests\x10\xc9\x97\x1a\x12\x11\n\x0bIPRateLimit\x10\xca\x97\x1a\x12\x12\n\x0c\x41PIRateLimit\x10\xbb\xcc\x18\x12\x16\n\x10\x45xecuteException\x10\xa0\xc2\x1e\x12\x19\n\x13StoreLayerException\x10\xa1\xc2\x1e\x12\x19\n\x13\x43MDBPluginException\x10\xa2\xc2\x1e\x12\x1b\n\x15ParseRoutingException\x10\xa4\xc2\x1e\x12\x1d\n\x17ParseRateLimitException\x10\xa5\xc2\x1e\x12\"\n\x1cParseCircuitBreakerException\x10\xa6\xc2\x1e\x12\x18\n\x12HeartbeatException\x10\xa7\xc2\x1e\x12\x1a\n\x14InstanceRegisTimeout\x10\xa8\xc2\x1e\x12 \n\x1aInvalidConfigFileGroupName\x10\xa1\xbb\x18\x12\x1b\n\x15InvalidConfigFileName\x10\xa2\xbb\x18\x12$\n\x1eInvalidConfigFileContentLength\x10\xa3\xbb\x18\x12\x1d\n\x17InvalidConfigFileFormat\x10\xa4\xbb\x18\x12\x1b\n\x15InvalidConfigFileTags\x10\xa5\xbb\x18\x12\"\n\x1cInvalidWatchConfigFileFormat\x10\xa6\xbb\x18\x12 \n\x1aNotFoundResourceConfigFile\x10\xa7\xbb\x18\x12#\n\x1dInvalidConfigFileTemplateName\x10\xa8\xbb\x18\x12 \n\x1a\x45ncryptConfigFileException\x10\xa9\xbb\x18\x12 \n\x1a\x44\x65\x63ryptConfigFileException\x10\xaa\xbb\x18\x12\x17\n\x11InvalidUserOwners\x10\x9a\xb8\x18\x12\x13\n\rInvalidUserID\x10\x9b\xb8\x18\x12\x19\n\x13InvalidUserPassword\x10\x9c\xb8\x18\x12\x17\n\x11InvalidUserMobile\x10\x9d\xb8\x18\x12\x16\n\x10InvalidUserEmail\x10\x9e\xb8\x18\x12\x1c\n\x16InvalidUserGroupOwners\x10\xa4\xb8\x18\x12\x18\n\x12InvalidUserGroupID\x10\xa5\xb8\x18\x12\x1f\n\x19InvalidAuthStrategyOwners\x10\xae\xb8\x18\x12\x1d\n\x17InvalidAuthStrategyName\x10\xaf\xb8\x18\x12\x1b\n\x15InvalidAuthStrategyID\x10\xb0\xb8\x18\x12\x1a\n\x14InvalidPrincipalType\x10\xb8\xb8\x18\x12\x11\n\x0bUserExisted\x10\xd7\xb6\x18\x12\x16\n\x10UserGroupExisted\x10\xd8\xb6\x18\x12\x1d\n\x17\x41uthStrategyRuleExisted\x10\xd9\xb6\x18\x12\x17\n\x11SubAccountExisted\x10\xda\xb6\x18\x12\x12\n\x0cNotFoundUser\x10\xb8\xb7\x18\x12\x17\n\x11NotFoundOwnerUser\x10\xb9\xb7\x18\x12\x17\n\x11NotFoundUserGroup\x10\xba\xb7\x18\x12\x1e\n\x18NotFoundAuthStrategyRule\x10\xbb\xb7\x18\x12,\n&NotAllowModifyDefaultStrategyPrincipal\x10\xfc\xb8\x18\x12(\n\"NotAllowModifyOwnerDefaultStrategy\x10\xfd\xb8\x18\x12\x13\n\rEmptyAutToken\x10\xea\xbc\x18\x12\x13\n\rTokenDisabled\x10\xeb\xbc\x18\x12\x15\n\x0fTokenNotExisted\x10\xec\xbc\x18\x12\x18\n\x12\x41uthTokenForbidden\x10\xb9\xcc\x18\x12\x1c\n\x16OperationRoleForbidden\x10\xba\xcc\x18\x42x\n.com.tencent.polaris.specification.api.v1.modelB\tCodeProtoZ;github.com/polarismesh/specification/source/go/api/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'code_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.tencent.polaris.specification.api.v1.modelB\tCodeProtoZ;github.com/polarismesh/specification/source/go/api/v1/model'
  _globals['_CODE']._serialized_start=19
  _globals['_CODE']._serialized_end=4815
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigDiscoverType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNKNOWN: _ClassVar[ConfigDiscoverType]
    CONFIG_FILE: _ClassVar[ConfigDiscoverType]
    CONFIG_FILE_LIST: _ClassVar[ConfigDiscoverType]
    CONFIG_GROUPS: _ClassVar[ConfigDiscoverType]
UNKNOWN: ConfigDiscoverType
CONFIG_FILE: ConfigDiscoverType
CONFIG_FILE_LIST: ConfigDiscoverType
CONFIG_GROUPS: ConfigDiscoverType

class ConfigFileGroup(_message.Message):
    __slots__ = ["id", "name", "namespace", "comment", "create_time", "create_by", "modify_time", "modify_by", "fileCount", "user_ids", "group_ids", "remove_user_ids", "remove_group_ids", "editable", "owner", "business", "department", "metadata"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_TIME_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    FILECOUNT_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_USER_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    BUSINESS_FIELD_NUMBER: _ClassVar[int]
    DEPARTMENT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.UInt64Value
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    create_time: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_time: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    fileCount: _wrappers_pb2.UInt64Value
    user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    editable: _wrappers_pb2.BoolValue
    owner: _wrappers_pb2.StringValue
    business: _wrappers_pb2.StringValue
    department: _wrappers_pb2.StringValue
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., fileCount: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., editable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., owner: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., business: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., department: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ConfigFile(_message.Message):
    __slots__ = ["id", "name", "namespace", "group", "content", "format", "comment", "status", "tags", "create_time", "create_by", "modify_time", "modify_by", "release_time", "release_by", "encrypted", "encrypt_algo"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_TIME_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    RELEASE_TIME_FIELD_NUMBER: _ClassVar[int]
    RELEASE_BY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    ENCRYPT_ALGO_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.UInt64Value
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    group: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    format: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    status: _wrappers_pb2.StringValue
    tags: _containers.RepeatedCompositeFieldContainer[ConfigFileTag]
    create_time: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_time: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    release_time: _wrappers_pb2.StringValue
    release_by: _wrappers_pb2.StringValue
    encrypted: _wrappers_pb2.BoolValue
    encrypt_algo: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., group: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., format: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., status: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tags: _Optional[_Iterable[_Union[ConfigFileTag, _Mapping]]] = ..., create_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., encrypted: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., encrypt_algo: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ConfigFileTag(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: _wrappers_pb2.StringValue
    value: _wrappers_pb2.StringValue
    def __init__(self, key: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., value: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ConfigFileRelease(_message.Message):
    __slots__ = ["id", "name", "namespace", "group", "file_name", "content", "comment", "md5", "version", "create_time", "create_by", "modify_time", "modify_by", "tags", "active", "format", "release_description", "type", "beta_labels"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    MD5_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_TIME_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    RELEASE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    BETA_LABELS_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.UInt64Value
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    group: _wrappers_pb2.StringValue
    file_name: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    md5: _wrappers_pb2.StringValue
    version: _wrappers_pb2.UInt64Value
    create_time: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_time: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    tags: _containers.RepeatedCompositeFieldContainer[ConfigFileTag]
    active: _wrappers_pb2.BoolValue
    format: _wrappers_pb2.StringValue
    release_description: _wrappers_pb2.StringValue
    type: _wrappers_pb2.StringValue
    beta_labels: _containers.RepeatedCompositeFieldContainer[_model_pb2.ClientLabel]
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., group: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., file_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., md5: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., version: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., create_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tags: _Optional[_Iterable[_Union[ConfigFileTag, _Mapping]]] = ..., active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., format: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., type: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., beta_labels: _Optional[_Iterable[_Union[_model_pb2.ClientLabel, _Mapping]]] = ...) -> None: ...

class ConfigFileReleaseHistory(_message.Message):
    __slots__ = ["id", "name", "namespace", "group", "file_name", "content", "format", "comment", "md5", "type", "status", "tags", "create_time", "create_by", "modify_time", "modify_by", "reason", "release_description"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    MD5_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_TIME_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    RELEASE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.UInt64Value
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    group: _wrappers_pb2.StringValue
    file_name: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    format: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    md5: _wrappers_pb2.StringValue
    type: _wrappers_pb2.StringValue
    status: _wrappers_pb2.StringValue
    tags: _containers.RepeatedCompositeFieldContainer[ConfigFileTag]
    create_time: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_time: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    reason: _wrappers_pb2.StringValue
    release_description: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., group: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., file_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., format: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., md5: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., type: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., status: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tags: _Optional[_Iterable[_Union[ConfigFileTag, _Mapping]]] = ..., create_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., reason: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ConfigFileTemplate(_message.Message):
    __slots__ = ["id", "name", "content", "format", "comment", "create_time", "create_by", "modify_time", "modify_by"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_TIME_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.UInt64Value
    name: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    format: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    create_time: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_time: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., format: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ClientConfigFileInfo(_message.Message):
    __slots__ = ["namespace", "group", "file_name", "content", "version", "md5", "tags", "encrypted", "public_key", "name", "release_time"]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MD5_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    RELEASE_TIME_FIELD_NUMBER: _ClassVar[int]
    namespace: _wrappers_pb2.StringValue
    group: _wrappers_pb2.StringValue
    file_name: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    version: _wrappers_pb2.UInt64Value
    md5: _wrappers_pb2.StringValue
    tags: _containers.RepeatedCompositeFieldContainer[ConfigFileTag]
    encrypted: _wrappers_pb2.BoolValue
    public_key: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    release_time: _wrappers_pb2.StringValue
    def __init__(self, namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., group: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., file_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., version: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., md5: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tags: _Optional[_Iterable[_Union[ConfigFileTag, _Mapping]]] = ..., encrypted: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., public_key: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_time: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class ClientWatchConfigFileRequest(_message.Message):
    __slots__ = ["client_ip", "service_name", "watch_files"]
    CLIENT_IP_FIELD_NUMBER: _ClassVar[int]
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    WATCH_FILES_FIELD_NUMBER: _ClassVar[int]
    client_ip: _wrappers_pb2.StringValue
    service_name: _wrappers_pb2.StringValue
    watch_files: _containers.RepeatedCompositeFieldContainer[ClientConfigFileInfo]
    def __init__(self, client_ip: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., watch_files: _Optional[_Iterable[_Union[ClientConfigFileInfo, _Mapping]]] = ...) -> None: ...

class ConfigFileExportRequest(_message.Message):
    __slots__ = ["namespace", "groups", "names"]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    NAMES_FIELD_NUMBER: _ClassVar[int]
    namespace: _wrappers_pb2.StringValue
    groups: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    names: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    def __init__(self, namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., groups: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., names: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ...) -> None: ...

class ConfigFilePublishInfo(_message.Message):
    __slots__ = ["release_name", "namespace", "group", "file_name", "content", "comment", "format", "release_description", "create_by", "modify_by", "tags"]
    RELEASE_NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    RELEASE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_BY_FIELD_NUMBER: _ClassVar[int]
    MODIFY_BY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    release_name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    group: _wrappers_pb2.StringValue
    file_name: _wrappers_pb2.StringValue
    content: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    format: _wrappers_pb2.StringValue
    release_description: _wrappers_pb2.StringValue
    create_by: _wrappers_pb2.StringValue
    modify_by: _wrappers_pb2.StringValue
    tags: _containers.RepeatedCompositeFieldContainer[ConfigFileTag]
    def __init__(self, release_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., group: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., file_name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., content: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., format: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., release_description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., create_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., modify_by: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tags: _Optional[_Iterable[_Union[ConfigFileTag, _Mapping]]] = ...) -> None: ...

class ConfigFileGroupRequest(_message.Message):
    __slots__ = ["revision", "config_file_group", "client_labels"]
    class ClientLabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FILE_GROUP_FIELD_NUMBER: _ClassVar[int]
    CLIENT_LABELS_FIELD_NUMBER: _ClassVar[int]
    revision: _wrappers_pb2.StringValue
    config_file_group: ConfigFileGroup
    client_labels: _containers.ScalarMap[str, str]
    def __init__(self, revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., config_file_group: _Optional[_Union[ConfigFileGroup, _Mapping]] = ..., client_labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ConfigDiscoverRequest(_message.Message):
    __slots__ = ["type", "namespace", "group", "revision"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    type: ConfigDiscoverType
    namespace: str
    group: str
    revision: str
    def __init__(self, type: _Optional[_Union[ConfigDiscoverType, str]] = ..., namespace: _Optional[str] = ..., group: _Optional[str] = ..., revision: _Optional[str] = ...) -> None: ...

class ConfigDiscoverResponse(_message.Message):
    __slots__ = ["code", "info", "revision", "type", "config_file", "config_file_names", "config_file_groups"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FILE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FILE_NAMES_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FILE_GROUPS_FIELD_NUMBER: _ClassVar[int]
    code: int
    info: str
    revision: str
    type: ConfigDiscoverType
    config_file: ClientConfigFileInfo
    config_file_names: _containers.RepeatedCompositeFieldContainer[ClientConfigFileInfo]
    config_file_groups: _containers.RepeatedCompositeFieldContainer[ConfigFileGroup]
    def __init__(self, code: _Optional[int] = ..., info: _Optional[str] = ..., revision: _Optional[str] = ..., type: _Optional[_Union[ConfigDiscoverType, str]] = ..., config_file: _Optional[_Union[ClientConfigFileInfo, _Mapping]] = ..., config_file_names: _Optional[_Iterable[_Union[ClientConfigFileInfo, _Mapping]]] = ..., config_file_groups: _Optional[_Iterable[_Union[ConfigFileGroup, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: namespace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fnamespace.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xc9\x07\n\tNamespace\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06owners\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x13total_service_count\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13total_service_count\x12^\n\x1btotal_health_instance_count\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1btotal_health_instance_count\x12P\n\x14total_instance_count\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14total_instance_count\x12\x38\n\x08user_ids\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\r \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12(\n\x02id\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08\x65\x64itable\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x11service_export_to\x18\x10 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x11service_export_toB}\n.com.tencent.polaris.specification.api.v1.modelB\x0eNamespaceProtoZ;github.com/polarismesh/specification/source/go/api/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'namespace_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.tencent.polaris.specification.api.v1.modelB\016NamespaceProtoZ;github.com/polarismesh/specification/source/go/api/v1/model'
  _globals['_NAMESPACE']._serialized_start=56
  _globals['_NAMESPACE']._serialized_end=1025
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Code(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    Unknown: _ClassVar[Code]
    ExecuteSuccess: _ClassVar[Code]
    DataNoChange: _ClassVar[Code]
    NoNeedUpdate: _ClassVar[Code]
    BadRequest: _ClassVar[Code]
    ParseException: _ClassVar[Code]
    EmptyRequest: _ClassVar[Code]
    BatchSizeOverLimit: _ClassVar[Code]
    InvalidDiscoverResource: _ClassVar[Code]
    InvalidRequestID: _ClassVar[Code]
    InvalidUserName: _ClassVar[Code]
    InvalidUserToken: _ClassVar[Code]
    InvalidParameter: _ClassVar[Code]
    EmptyQueryParameter: _ClassVar[Code]
    InvalidQueryInsParameter: _ClassVar[Code]
    InvalidNamespaceName: _ClassVar[Code]
    InvalidNamespaceOwners: _ClassVar[Code]
    InvalidNamespaceToken: _ClassVar[Code]
    InvalidServiceName: _ClassVar[Code]
    InvalidServiceOwners: _ClassVar[Code]
    InvalidServiceToken: _ClassVar[Code]
    InvalidServiceMetadata: _ClassVar[Code]
    InvalidServicePorts: _ClassVar[Code]
    InvalidServiceBusiness: _ClassVar[Code]
    InvalidServiceDepartment: _ClassVar[Code]
    InvalidServiceCMDB: _ClassVar[Code]
    InvalidServiceComment: _ClassVar[Code]
    InvalidServiceAliasComment: _ClassVar[Code]
    InvalidInstanceID: _ClassVar[Code]
    InvalidInstanceHost: _ClassVar[Code]
    InvalidInstancePort: _ClassVar[Code]
    InvalidServiceAlias: _ClassVar[Code]
    InvalidNamespaceWithAlias: _ClassVar[Code]
    InvalidServiceAliasOwners: _ClassVar[Code]
    InvalidInstanceProtocol: _ClassVar[Code]
    InvalidInstanceVersion: _ClassVar[Code]
    InvalidInstanceLogicSet: _ClassVar[Code]
    InvalidInstanceIsolate: _ClassVar[Code]
    HealthCheckNotOpen: _ClassVar[Code]
    HeartbeatOnDisabledIns: _ClassVar[Code]
    HeartbeatExceedLimit: _ClassVar[Code]
    HeartbeatTypeNotFound: _ClassVar[Code]
    InvalidMetadata: _ClassVar[Code]
    InvalidRateLimitID: _ClassVar[Code]
    InvalidRateLimitLabels: _ClassVar[Code]
    InvalidRateLimitAmounts: _ClassVar[Code]
    InvalidRateLimitName: _ClassVar[Code]
    InvalidCircuitBreakerID: _ClassVar[Code]
    InvalidCircuitBreakerVersion: _ClassVar[Code]
    InvalidCircuitBreakerName: _ClassVar[Code]
    InvalidCircuitBreakerNamespace: _ClassVar[Code]
    InvalidCircuitBreakerOwners: _ClassVar[Code]
    InvalidCircuitBreakerToken: _ClassVar[Code]
    InvalidCircuitBreakerBusiness: _ClassVar[Code]
    InvalidCircuitBreakerDepartment: _ClassVar[Code]
    InvalidCircuitBreakerComment: _ClassVar[Code]
    CircuitBreakerRuleExisted: _ClassVar[Code]
    InvalidRoutingID: _ClassVar[Code]
    InvalidRoutingPolicy: _ClassVar[Code]
    InvalidRoutingName: _ClassVar[Code]
    InvalidRoutingPriority: _ClassVar[Code]
    InvalidFaultDetectID: _ClassVar[Code]
    InvalidFaultDetectName: _ClassVar[Code]
    InvalidFaultDetectNamespace: _ClassVar[Code]
    FaultDetectRuleExisted: _ClassVar[Code]
    InvalidMatchRule: _ClassVar[Code]
    ServicesExistedMesh: _ClassVar[Code]
    ResourcesExistedMesh: _ClassVar[Code]
    InvalidMeshParameter: _ClassVar[Code]
    InvalidPlatformID: _ClassVar[Code]
    InvalidPlatformName: _ClassVar[Code]
    InvalidPlatformDomain: _ClassVar[Code]
    InvalidPlatformQPS: _ClassVar[Code]
    InvalidPlatformToken: _ClassVar[Code]
    InvalidPlatformOwner: _ClassVar[Code]
    InvalidPlatformDepartment: _ClassVar[Code]
    InvalidPlatformComment: _ClassVar[Code]
    NotFoundPlatform: _ClassVar[Code]
    InvalidFluxRateLimitId: _ClassVar[Code]
    InvalidFluxRateLimitQps: _ClassVar[Code]
    InvalidFluxRateLimitSetKey: _ClassVar[Code]
    ExistedResource: _ClassVar[Code]
    NotFoundResource: _ClassVar[Code]
    NamespaceExistedServices: _ClassVar[Code]
    ServiceExistedInstances: _ClassVar[Code]
    ServiceExistedRoutings: _ClassVar[Code]
    ServiceExistedRateLimits: _ClassVar[Code]
    ExistReleasedConfig: _ClassVar[Code]
    SameInstanceRequest: _ClassVar[Code]
    ServiceExistedCircuitBreakers: _ClassVar[Code]
    ServiceExistedAlias: _ClassVar[Code]
    NamespaceExistedMeshResources: _ClassVar[Code]
    NamespaceExistedCircuitBreakers: _ClassVar[Code]
    ServiceSubscribedByMeshes: _ClassVar[Code]
    ServiceExistedFluxRateLimits: _ClassVar[Code]
    NamespaceExistedConfigGroups: _ClassVar[Code]
    NotFoundService: _ClassVar[Code]
    NotFoundRouting: _ClassVar[Code]
    NotFoundInstance: _ClassVar[Code]
    NotFoundServiceAlias: _ClassVar[Code]
    NotFoundNamespace: _ClassVar[Code]
    NotFoundSourceService: _ClassVar[Code]
    NotFoundRateLimit: _ClassVar[Code]
    NotFoundCircuitBreaker: _ClassVar[Code]
    NotFoundMasterConfig: _ClassVar[Code]
    NotFoundTagConfig: _ClassVar[Code]
    NotFoundTagConfigOrService: _ClassVar[Code]
    ClientAPINotOpen: _ClassVar[Code]
    NotAllowBusinessService: _ClassVar[Code]
    NotAllowAliasUpdate: _ClassVar[Code]
    NotAllowAliasCreateInstance: _ClassVar[Code]
    NotAllowAliasCreateRouting: _ClassVar[Code]
    NotAllowCreateAliasForAlias: _ClassVar[Code]
    NotAllowAliasCreateRateLimit: _ClassVar[Code]
    NotAllowAliasBindRule: _ClassVar[Code]
    NotAllowDifferentNamespaceBindRule: _ClassVar[Code]
    Unauthorized: _ClassVar[Code]
    NotAllowedAccess: _ClassVar[Code]
    CMDBNotFindHost: _ClassVar[Code]
    DataConflict: _ClassVar[Code]
    InstanceTooManyRequests: _ClassVar[Code]
    IPRateLimit: _ClassVar[Code]
    APIRateLimit: _ClassVar[Code]
    ExecuteException: _ClassVar[Code]
    StoreLayerException: _ClassVar[Code]
    CMDBPluginException: _ClassVar[Code]
    ParseRoutingException: _ClassVar[Code]
    ParseRateLimitException: _ClassVar[Code]
    ParseCircuitBreakerException: _ClassVar[Code]
    HeartbeatException: _ClassVar[Code]
    InstanceRegisTimeout: _ClassVar[Code]
    InvalidConfigFileGroupName: _ClassVar[Code]
    InvalidConfigFileName: _ClassVar[Code]
    InvalidConfigFileContentLength: _ClassVar[Code]
    InvalidConfigFileFormat: _ClassVar[Code]
    InvalidConfigFileTags: _ClassVar[Code]
    InvalidWatchConfigFileFormat: _ClassVar[Code]
    NotFoundResourceConfigFile: _ClassVar[Code]
    InvalidConfigFileTemplateName: _ClassVar[Code]
    EncryptConfigFileException: _ClassVar[Code]
    DecryptConfigFileException: _ClassVar[Code]
    InvalidUserOwners: _ClassVar[Code]
    InvalidUserID: _ClassVar[Code]
    InvalidUserPassword: _ClassVar[Code]
    InvalidUserMobile: _ClassVar[Code]
    InvalidUserEmail: _ClassVar[Code]
    InvalidUserGroupOwners: _ClassVar[Code]
    InvalidUserGroupID: _ClassVar[Code]
    InvalidAuthStrategyOwners: _ClassVar[Code]
    InvalidAuthStrategyName: _ClassVar[Code]
    InvalidAuthStrategyID: _ClassVar[Code]
    InvalidPrincipalType: _ClassVar[Code]
    UserExisted: _ClassVar[Code]
    UserGroupExisted: _ClassVar[Code]
    AuthStrategyRuleExisted: _ClassVar[Code]
    SubAccountExisted: _ClassVar[Code]
    NotFoundUser: _ClassVar[Code]
    NotFoundOwnerUser: _ClassVar[Code]
    NotFoundUserGroup: _ClassVar[Code]
    NotFoundAuthStrategyRule: _ClassVar[Code]
    NotAllowModifyDefaultStrategyPrincipal: _ClassVar[Code]
    NotAllowModifyOwnerDefaultStrategy: _ClassVar[Code]
    EmptyAutToken: _ClassVar[Code]
    TokenDisabled: _ClassVar[Code]
    TokenNotExisted: _ClassVar[Code]
    AuthTokenForbidden: _ClassVar[Code]
    OperationRoleForbidden: _ClassVar[Code]
Unknown: Code
ExecuteSuccess: Code
DataNoChange: Code
NoNeedUpdate: Code
BadRequest: Code
ParseException: Code
EmptyRequest: Code
BatchSizeOverLimit: Code
InvalidDiscoverResource: Code
InvalidRequestID: Code
InvalidUserName: Code
InvalidUserToken: Code
InvalidParameter: Code
EmptyQueryParameter: Code
InvalidQueryInsParameter: Code
InvalidNamespaceName: Code
InvalidNamespaceOwners: Code
InvalidNamespaceToken: Code
InvalidServiceName: Code
InvalidServiceOwners: Code
InvalidServiceToken: Code
InvalidServiceMetadata: Code
InvalidServicePorts: Code
InvalidServiceBusiness: Code
InvalidServiceDepartment: Code
InvalidServiceCMDB: Code
InvalidServiceComment: Code
InvalidServiceAliasComment: Code
InvalidInstanceID: Code
InvalidInstanceHost: Code
InvalidInstancePort: Code
InvalidServiceAlias: Code
InvalidNamespaceWithAlias: Code
InvalidServiceAliasOwners: Code
InvalidInstanceProtocol: Code
InvalidInstanceVersion: Code
InvalidInstanceLogicSet: Code
InvalidInstanceIsolate: Code
HealthCheckNotOpen: Code
HeartbeatOnDisabledIns: Code
HeartbeatExceedLimit: Code
HeartbeatTypeNotFound: Code
InvalidMetadata: Code
InvalidRateLimitID: Code
InvalidRateLimitLabels: Code
InvalidRateLimitAmounts: Code
InvalidRateLimitName: Code
InvalidCircuitBreakerID: Code
InvalidCircuitBreakerVersion: Code
InvalidCircuitBreakerName: Code
InvalidCircuitBreakerNamespace: Code
InvalidCircuitBreakerOwners: Code
InvalidCircuitBreakerToken: Code
InvalidCircuitBreakerBusiness: Code
InvalidCircuitBreakerDepartment: Code
InvalidCircuitBreakerComment: Code
CircuitBreakerRuleExisted: Code
InvalidRoutingID: Code
InvalidRoutingPolicy: Code
InvalidRoutingName: Code
InvalidRoutingPriority: Code
InvalidFaultDetectID: Code
InvalidFaultDetectName: Code
InvalidFaultDetectNamespace: Code
FaultDetectRuleExisted: Code
InvalidMatchRule: Code
ServicesExistedMesh: Code
ResourcesExistedMesh: Code
InvalidMeshParameter: Code
InvalidPlatformID: Code
InvalidPlatformName: Code
InvalidPlatformDomain: Code
InvalidPlatformQPS: Code
InvalidPlatformToken: Code
InvalidPlatformOwner: Code
InvalidPlatformDepartment: Code
InvalidPlatformComment: Code
NotFoundPlatform: Code
InvalidFluxRateLimitId: Code
InvalidFluxRateLimitQps: Code
InvalidFluxRateLimitSetKey: Code
ExistedResource: Code
NotFoundResource: Code
NamespaceExistedServices: Code
ServiceExistedInstances: Code
ServiceExistedRoutings: Code
ServiceExistedRateLimits: Code
ExistReleasedConfig: Code
SameInstanceRequest: Code
ServiceExistedCircuitBreakers: Code
ServiceExistedAlias: Code
NamespaceExistedMeshResources: Code
NamespaceExistedCircuitBreakers: Code
ServiceSubscribedByMeshes: Code
ServiceExistedFluxRateLimits: Code
NamespaceExistedConfigGroups: Code
NotFoundService: Code
NotFoundRouting: Code
NotFoundInstance: Code
NotFoundServiceAlias: Code
NotFoundNamespace: Code
NotFoundSourceService: Code
NotFoundRateLimit: Code
NotFoundCircuitBreaker: Code
NotFoundMasterConfig: Code
NotFoundTagConfig: Code
NotFoundTagConfigOrService: Code
ClientAPINotOpen: Code
NotAllowBusinessService: Code
NotAllowAliasUpdate: Code
NotAllowAliasCreateInstance: Code
NotAllowAliasCreateRouting: Code
NotAllowCreateAliasForAlias: Code
NotAllowAliasCreateRateLimit: Code
NotAllowAliasBindRule: Code
NotAllowDifferentNamespaceBindRule: Code
Unauthorized: Code
NotAllowedAccess: Code
CMDBNotFindHost: Code
DataConflict: Code
InstanceTooManyRequests: Code
IPRateLimit: Code
APIRateLimit: Code
ExecuteException: Code
StoreLayerException: Code
CMDBPluginException: Code
ParseRoutingException: Code
ParseRateLimitException: Code
ParseCircuitBreakerException: Code
HeartbeatException: Code
InstanceRegisTimeout: Code
InvalidConfigFileGroupName: Code
InvalidConfigFileName: Code
InvalidConfigFileContentLength: Code
InvalidConfigFileFormat: Code
InvalidConfigFileTags: Code
InvalidWatchConfigFileFormat: Code
NotFoundResourceConfigFile: Code
InvalidConfigFileTemplateName: Code
EncryptConfigFileException: Code
DecryptConfigFileException: Code
InvalidUserOwners: Code
InvalidUserID: Code
InvalidUserPassword: Code
InvalidUserMobile: Code
InvalidUserEmail: Code
InvalidUserGroupOwners: Code
InvalidUserGroupID: Code
InvalidAuthStrategyOwners: Code
InvalidAuthStrategyName: Code
InvalidAuthStrategyID: Code
InvalidPrincipalType: Code
UserExisted: Code
UserGroupExisted: Code
AuthStrategyRuleExisted: Code
SubAccountExisted: Code
NotFoundUser: Code
NotFoundOwnerUser: Code
NotFoundUserGroup: Code
NotFoundAuthStrategyRule: Code
NotAllowModifyDefaultStrategyPrincipal: Code
NotAllowModifyOwnerDefaultStrategy: Code
EmptyAutToken: Code
TokenDisabled: Code
TokenNotExisted: Code
AuthTokenForbidden: Code
OperationRoleForbidden: Code



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..service_manage import client_pb2 as client__pb2
from ..service_manage import contract_pb2 as contract__pb2
from ..service_manage import heartbeat_pb2 as heartbeat__pb2
from ..service_manage import request_pb2 as request__pb2
from ..service_manage import response_pb2 as response__pb2
from ..service_manage import service_pb2 as service__pb2


class PolarisGRPCStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReportClient = channel.unary_unary(
                '/v1.PolarisGRPC/ReportClient',
                request_serializer=client__pb2.Client.SerializeToString,
                response_deserializer=response__pb2.Response.FromString,
                )
        self.RegisterInstance = channel.unary_unary(
                '/v1.PolarisGRPC/RegisterInstance',
                request_serializer=service__pb2.Instance.SerializeToString,
                response_deserializer=response__pb2.Response.FromString,
                )
        self.DeregisterInstance = channel.unary_unary(
                '/v1.PolarisGRPC/DeregisterInstance',
                request_serializer=service__pb2.Instance.SerializeToString,
                response_deserializer=response__pb2.Response.FromString,
                )
        self.Discover = channel.stream_stream(
                '/v1.PolarisGRPC/Discover',
                request_serializer=request__pb2.DiscoverRequest.SerializeToString,
                response_deserializer=response__pb2.DiscoverResponse.FromString,
                )
        self.Heartbeat = channel.unary_unary(
                '/v1.PolarisGRPC/Heartbeat',
                request_serializer=service__pb2.Instance.SerializeToString,
                response_deserializer=response__pb2.Response.FromString,
                )


class PolarisGRPCServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ReportClient(self, request, context):
        """客户端上报
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterInstance(self, request, context):
        """被调方注册服务实例
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeregisterInstance(self, request, context):
        """被调方反注册服务实例
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Discover(self, request_iterator, context):
        """统一发现接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """被调方上报心跳
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolarisGRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReportClient': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportClient,
                    request_deserializer=client__pb2.Client.FromString,
                    response_serializer=response__pb2.Response.SerializeToString,
            ),
            'RegisterInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterInstance,
                    request_deserializer=service__pb2.Instance.FromString,
                    response_serializer=response__pb2.Response.SerializeToString,
            ),
            'DeregisterInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.DeregisterInstance,
                    request_deserializer=service__pb2.Instance.FromString,
                    response_serializer=response__pb2.Response.SerializeToString,
            ),
            'Discover': grpc.stream_stream_rpc_method_handler(
                    servicer.Discover,
                    request_deserializer=request__pb2.DiscoverRequest.FromString,
                    response_serializer=response__pb2.DiscoverResponse.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=service__pb2.Instance.FromString,
                    response_serializer=response__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.PolarisGRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PolarisGRPC(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ReportClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisGRPC/ReportClient',
            client__pb2.Client.SerializeToString,
            response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisGRPC/RegisterInstance',
            service__pb2.Instance.SerializeToString,
            response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeregisterInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisGRPC/DeregisterInstance',
            service__pb2.Instance.SerializeToString,
            response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Discover(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/v1.PolarisGRPC/Discover',
            request__pb2.DiscoverRequest.SerializeToString,
            response__pb2.DiscoverResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisGRPC/Heartbeat',
            service__pb2.Instance.SerializeToString,
            response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class PolarisHeartbeatGRPCStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BatchHeartbeat = channel.stream_stream(
                '/v1.PolarisHeartbeatGRPC/BatchHeartbeat',
                request_serializer=heartbeat__pb2.HeartbeatsRequest.SerializeToString,
                response_deserializer=heartbeat__pb2.HeartbeatsResponse.FromString,
                )
        self.BatchGetHeartbeat = channel.unary_unary(
                '/v1.PolarisHeartbeatGRPC/BatchGetHeartbeat',
                request_serializer=heartbeat__pb2.GetHeartbeatsRequest.SerializeToString,
                response_deserializer=heartbeat__pb2.GetHeartbeatsResponse.FromString,
                )
        self.BatchDelHeartbeat = channel.unary_unary(
                '/v1.PolarisHeartbeatGRPC/BatchDelHeartbeat',
                request_serializer=heartbeat__pb2.DelHeartbeatsRequest.SerializeToString,
                response_deserializer=heartbeat__pb2.DelHeartbeatsResponse.FromString,
                )


class PolarisHeartbeatGRPCServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BatchHeartbeat(self, request_iterator, context):
        """被调方批量上报心跳
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetHeartbeat(self, request, context):
        """批量获取心跳记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDelHeartbeat(self, request, context):
        """批量删除心跳记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolarisHeartbeatGRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BatchHeartbeat': grpc.stream_stream_rpc_method_handler(
                    servicer.BatchHeartbeat,
                    request_deserializer=heartbeat__pb2.HeartbeatsRequest.FromString,
                    response_serializer=heartbeat__pb2.HeartbeatsResponse.SerializeToString,
            ),
            'BatchGetHeartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetHeartbeat,
                    request_deserializer=heartbeat__pb2.GetHeartbeatsRequest.FromString,
                    response_serializer=heartbeat__pb2.GetHeartbeatsResponse.SerializeToString,
            ),
            'BatchDelHeartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDelHeartbeat,
                    request_deserializer=heartbeat__pb2.DelHeartbeatsRequest.FromString,
                    response_serializer=heartbeat__pb2.DelHeartbeatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.PolarisHeartbeatGRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PolarisHeartbeatGRPC(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BatchHeartbeat(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/v1.PolarisHeartbeatGRPC/BatchHeartbeat',
            heartbeat__pb2.HeartbeatsRequest.SerializeToString,
            heartbeat__pb2.HeartbeatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetHeartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisHeartbeatGRPC/BatchGetHeartbeat',
            heartbeat__pb2.GetHeartbeatsRequest.SerializeToString,
            heartbeat__pb2.GetHeartbeatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchDelHeartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisHeartbeatGRPC/BatchDelHeartbeat',
            heartbeat__pb2.DelHeartbeatsRequest.SerializeToString,
            heartbeat__pb2.DelHeartbeatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class PolarisServiceContractGRPCStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReportServiceContract = channel.unary_unary(
                '/v1.PolarisServiceContractGRPC/ReportServiceContract',
                request_serializer=contract__pb2.ServiceContract.SerializeToString,
                response_deserializer=response__pb2.Response.FromString,
                )


class PolarisServiceContractGRPCServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ReportServiceContract(self, request, context):
        """上报服务契约
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolarisServiceContractGRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReportServiceContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportServiceContract,
                    request_deserializer=contract__pb2.ServiceContract.FromString,
                    response_serializer=response__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.PolarisServiceContractGRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PolarisServiceContractGRPC(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ReportServiceContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisServiceContractGRPC/ReportServiceContract',
            contract__pb2.ServiceContract.SerializeToString,
            response__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fratelimit.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x0bmodel.proto\"T\n\tRateLimit\x12\x17\n\x05rules\x18\x01 \x03(\x0b\x32\x08.v1.Rule\x12.\n\x08revision\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x0b\n\x04Rule\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07service\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12$\n\x06subset\x18\x04 \x03(\x0b\x32\x14.v1.Rule.SubsetEntry\x12.\n\x08priority\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x08resource\x18\x06 \x01(\x0e\x32\x11.v1.Rule.Resource\x12\x1b\n\x04type\x18\x07 \x01(\x0e\x32\r.v1.Rule.Type\x12$\n\x06labels\x18\x08 \x03(\x0b\x32\x14.v1.Rule.LabelsEntry\x12\x1b\n\x07\x61mounts\x18\t \x03(\x0b\x32\n.v1.Amount\x12,\n\x06\x61\x63tion\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07\x64isable\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x06report\x18\x0c \x01(\x0b\x32\n.v1.Report\x12+\n\x05\x63time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x12$\n\x08\x61\x64juster\x18\x11 \x01(\x0b\x32\x12.v1.AmountAdjuster\x12@\n\rregex_combine\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\rregex_combine\x12(\n\x0b\x61mount_mode\x18\x13 \x01(\x0e\x32\x13.v1.Rule.AmountMode\x12\'\n\x08\x66\x61ilover\x18\x14 \x01(\x0e\x32\x15.v1.Rule.FailoverType\x12%\n\x07\x63luster\x18\x15 \x01(\x0b\x32\x14.v1.RateLimitCluster\x12\x1f\n\x06method\x18\x16 \x01(\x0b\x32\x0f.v1.MatchString\x12$\n\targuments\x18\x17 \x03(\x0b\x32\x11.v1.MatchArgument\x12*\n\x04name\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x65time\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x46\n\x0fmax_queue_delay\x18\x1a \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0fmax_queue_delay\x1a>\n\x0bSubsetEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"$\n\x08Resource\x12\x07\n\x03QPS\x10\x00\x12\x0f\n\x0b\x43ONCURRENCY\x10\x01\"\x1d\n\x04Type\x12\n\n\x06GLOBAL\x10\x00\x12\t\n\x05LOCAL\x10\x01\"1\n\nAmountMode\x12\x10\n\x0cGLOBAL_TOTAL\x10\x00\x12\x11\n\rSHARE_EQUALLY\x10\x01\"5\n\x0c\x46\x61iloverType\x12\x12\n\x0e\x46\x41ILOVER_LOCAL\x10\x00\x12\x11\n\rFAILOVER_PASS\x10\x01\"\xbc\x01\n\rMatchArgument\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.v1.MatchArgument.Type\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x1e\n\x05value\x18\x03 \x01(\x0b\x32\x0f.v1.MatchString\"X\n\x04Type\x12\n\n\x06\x43USTOM\x10\x00\x12\n\n\x06METHOD\x10\x01\x12\n\n\x06HEADER\x10\x02\x12\t\n\x05QUERY\x10\x03\x12\x12\n\x0e\x43\x41LLER_SERVICE\x10\x04\x12\r\n\tCALLER_IP\x10\x05\"r\n\x10RateLimitCluster\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x80\x02\n\x06\x41mount\x12/\n\tmaxAmount\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x30\n\rvalidDuration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\tprecision\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bstartAmount\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\tminAmount\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"j\n\x06Report\x12+\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\ramountPercent\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"0\n\x0e\x41mountAdjuster\x12\x1e\n\x05\x63limb\x18\x01 \x01(\x0b\x32\x0f.v1.ClimbConfig\"\xec\x0b\n\x0b\x43limbConfig\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.v1.ClimbConfig.MetricConfig\x12-\n\x06policy\x18\x03 \x01(\x0b\x32\x1d.v1.ClimbConfig.TriggerPolicy\x12\x33\n\nthrottling\x18\x04 \x01(\x0b\x32\x1f.v1.ClimbConfig.ClimbThrottling\x1a\x9d\x01\n\x0cMetricConfig\x12)\n\x06window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\tprecision\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0ereportInterval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\xa7\x05\n\rTriggerPolicy\x12:\n\terrorRate\x18\x01 \x01(\x0b\x32\'.v1.ClimbConfig.TriggerPolicy.ErrorRate\x12\x38\n\x08slowRate\x18\x02 \x01(\x0b\x32&.v1.ClimbConfig.TriggerPolicy.SlowRate\x1a\x8d\x03\n\tErrorRate\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16requestVolumeThreshold\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\terrorRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12G\n\x08specials\x18\x04 \x03(\x0b\x32\x35.v1.ClimbConfig.TriggerPolicy.ErrorRate.SpecialConfig\x1a\x9c\x01\n\rSpecialConfig\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\nerrorCodes\x18\x02 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\terrorRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\x8f\x01\n\x08SlowRate\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x05maxRt\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\x08slowRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\xd4\x03\n\x0f\x43limbThrottling\x12:\n\x15\x63oldBelowTuneDownRate\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x13\x63oldBelowTuneUpRate\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12:\n\x15\x63oldAboveTuneDownRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x13\x63oldAboveTuneUpRate\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12;\n\x16limitThresholdToTuneUp\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\rjudgeDuration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x0ctuneUpPeriod\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\x0etuneDownPeriod\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x8f\x01\n7com.tencent.polaris.specification.api.v1.traffic.manageB\x0eRateLimitProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ratelimit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.traffic.manageB\016RateLimitProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manage'
  _RULE_SUBSETENTRY._options = None
  _RULE_SUBSETENTRY._serialized_options = b'8\001'
  _RULE_LABELSENTRY._options = None
  _RULE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RATELIMIT']._serialized_start=100
  _globals['_RATELIMIT']._serialized_end=184
  _globals['_RULE']._serialized_start=187
  _globals['_RULE']._serialized_end=1636
  _globals['_RULE_SUBSETENTRY']._serialized_start=1335
  _globals['_RULE_SUBSETENTRY']._serialized_end=1397
  _globals['_RULE_LABELSENTRY']._serialized_start=1399
  _globals['_RULE_LABELSENTRY']._serialized_end=1461
  _globals['_RULE_RESOURCE']._serialized_start=1463
  _globals['_RULE_RESOURCE']._serialized_end=1499
  _globals['_RULE_TYPE']._serialized_start=1501
  _globals['_RULE_TYPE']._serialized_end=1530
  _globals['_RULE_AMOUNTMODE']._serialized_start=1532
  _globals['_RULE_AMOUNTMODE']._serialized_end=1581
  _globals['_RULE_FAILOVERTYPE']._serialized_start=1583
  _globals['_RULE_FAILOVERTYPE']._serialized_end=1636
  _globals['_MATCHARGUMENT']._serialized_start=1639
  _globals['_MATCHARGUMENT']._serialized_end=1827
  _globals['_MATCHARGUMENT_TYPE']._serialized_start=1739
  _globals['_MATCHARGUMENT_TYPE']._serialized_end=1827
  _globals['_RATELIMITCLUSTER']._serialized_start=1829
  _globals['_RATELIMITCLUSTER']._serialized_end=1943
  _globals['_AMOUNT']._serialized_start=1946
  _globals['_AMOUNT']._serialized_end=2202
  _globals['_REPORT']._serialized_start=2204
  _globals['_REPORT']._serialized_end=2310
  _globals['_AMOUNTADJUSTER']._serialized_start=2312
  _globals['_AMOUNTADJUSTER']._serialized_end=2360
  _globals['_CLIMBCONFIG']._serialized_start=2363
  _globals['_CLIMBCONFIG']._serialized_end=3879
  _globals['_CLIMBCONFIG_METRICCONFIG']._serialized_start=2569
  _globals['_CLIMBCONFIG_METRICCONFIG']._serialized_end=2726
  _globals['_CLIMBCONFIG_TRIGGERPOLICY']._serialized_start=2729
  _globals['_CLIMBCONFIG_TRIGGERPOLICY']._serialized_end=3408
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE']._serialized_start=2865
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE']._serialized_end=3262
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE_SPECIALCONFIG']._serialized_start=3106
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE_SPECIALCONFIG']._serialized_end=3262
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_SLOWRATE']._serialized_start=3265
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_SLOWRATE']._serialized_end=3408
  _globals['_CLIMBCONFIG_CLIMBTHROTTLING']._serialized_start=3411
  _globals['_CLIMBCONFIG_CLIMBTHROTTLING']._serialized_end=3879
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Location(_message.Message):
    __slots__ = ["region", "zone", "campus"]
    REGION_FIELD_NUMBER: _ClassVar[int]
    ZONE_FIELD_NUMBER: _ClassVar[int]
    CAMPUS_FIELD_NUMBER: _ClassVar[int]
    region: _wrappers_pb2.StringValue
    zone: _wrappers_pb2.StringValue
    campus: _wrappers_pb2.StringValue
    def __init__(self, region: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., zone: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., campus: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class MatchString(_message.Message):
    __slots__ = ["type", "value", "value_type"]
    class MatchStringType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        EXACT: _ClassVar[MatchString.MatchStringType]
        REGEX: _ClassVar[MatchString.MatchStringType]
        NOT_EQUALS: _ClassVar[MatchString.MatchStringType]
        IN: _ClassVar[MatchString.MatchStringType]
        NOT_IN: _ClassVar[MatchString.MatchStringType]
        RANGE: _ClassVar[MatchString.MatchStringType]
    EXACT: MatchString.MatchStringType
    REGEX: MatchString.MatchStringType
    NOT_EQUALS: MatchString.MatchStringType
    IN: MatchString.MatchStringType
    NOT_IN: MatchString.MatchStringType
    RANGE: MatchString.MatchStringType
    class ValueType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        TEXT: _ClassVar[MatchString.ValueType]
        PARAMETER: _ClassVar[MatchString.ValueType]
        VARIABLE: _ClassVar[MatchString.ValueType]
    TEXT: MatchString.ValueType
    PARAMETER: MatchString.ValueType
    VARIABLE: MatchString.ValueType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    type: MatchString.MatchStringType
    value: _wrappers_pb2.StringValue
    value_type: MatchString.ValueType
    def __init__(self, type: _Optional[_Union[MatchString.MatchStringType, str]] = ..., value: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., value_type: _Optional[_Union[MatchString.ValueType, str]] = ...) -> None: ...

class StringList(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...

class Summary(_message.Message):
    __slots__ = ["total_service_count", "total_health_instance_count", "total_instance_count"]
    TOTAL_SERVICE_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_HEALTH_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    total_service_count: int
    total_health_instance_count: int
    total_instance_count: int
    def __init__(self, total_service_count: _Optional[int] = ..., total_health_instance_count: _Optional[int] = ..., total_instance_count: _Optional[int] = ...) -> None: ...

class ClientLabel(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: MatchString
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MatchString, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_config_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..config_manage import config_file_pb2 as config__file__pb2
from ..config_manage import config_file_response_pb2 as config__file__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15grpc_config_api.proto\x12\x02v1\x1a\x11\x63onfig_file.proto\x1a\x1a\x63onfig_file_response.proto2\x96\x04\n\x11PolarisConfigGRPC\x12\x45\n\rGetConfigFile\x12\x18.v1.ClientConfigFileInfo\x1a\x18.v1.ConfigClientResponse\"\x00\x12>\n\x10\x43reateConfigFile\x12\x0e.v1.ConfigFile\x1a\x18.v1.ConfigClientResponse\"\x00\x12>\n\x10UpdateConfigFile\x12\x0e.v1.ConfigFile\x1a\x18.v1.ConfigClientResponse\"\x00\x12\x46\n\x11PublishConfigFile\x12\x15.v1.ConfigFileRelease\x1a\x18.v1.ConfigClientResponse\"\x00\x12P\n\x10WatchConfigFiles\x12 .v1.ClientWatchConfigFileRequest\x1a\x18.v1.ConfigClientResponse\"\x00\x12W\n\x19GetConfigFileMetadataList\x12\x1a.v1.ConfigFileGroupRequest\x1a\x1c.v1.ConfigClientListResponse\"\x00\x12G\n\x08\x44iscover\x12\x19.v1.ConfigDiscoverRequest\x1a\x1a.v1.ConfigDiscoverResponse\"\x00(\x01\x30\x01\x42\x97\x01\n6com.tencent.polaris.specification.api.v1.config.manageB\x18PolarisConfigGRPCServiceZCgithub.com/polarismesh/specification/source/go/api/v1/config_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_config_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.tencent.polaris.specification.api.v1.config.manageB\030PolarisConfigGRPCServiceZCgithub.com/polarismesh/specification/source/go/api/v1/config_manage'
  _globals['_POLARISCONFIGGRPC']._serialized_start=77
  _globals['_POLARISCONFIGGRPC']._serialized_end=611
# @@protoc_insertion_point(module_scope)



from ..config_manage import config_file_pb2 as _config_file_pb2
from ..config_manage import config_file_response_pb2 as _config_file_response_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
